@@ -93,59 +93,55 @@ searchConQuestSys <- function(searchString, mySys, value = TRUE, ignore.case = T
 #'     (e.g., PISA Mean = 500, SD = 100).
 #'     Uses the method described in the PISA 2012 technical manual.
 #'
-#' @param x A concatenated vector of varnames in data, PV1, PV2, ..., PVm.
+#' @param data A data frame or matrix that contains the PVs
 #' @param mT The desired mean of the PVs
 #' @param sdT The desired sd of the PVs
-#' @param weights The name of the weight variable in 'data' used to
-#'     caulculate the mean and SD accross the PVs
-#' @param data The data frame that contains the PVs and weights.
-#' @param addToDf A Boolean, if TRUE, the transformed PVs are coerced
-#'     into the DF, data, with name data$x_T (not yet implmented).
-#' @param debug A temporary flag to spit-out objects to global env for chekcing.
-#'     Will be removed when pushed to CRAN
-#' @return a List of transofrmed PVs with as many elements as PVs were listed in 'x'.
-transformPvs <- function(x, mT = 0, sdT = 1, weights, data, addToDf = FALSE, debug = TRUE) {
-  # setup
-  results <- list()
-  pvDataList <- list()
-  weightDataList <- list()
-  m <- length(x)
-  dataName <- deparse(substitute(data)) # name of data frame
-
-  # put the PVs and weights in a list to calculate the pooled mean and var
-  i <- 1
-  for (pv in x) {
-    # add cehcking that i is less than m
-    pvDataList[[i]] <- eval(parse(text = paste0(dataName, "$", pv)))
-    weightDataList[[i]] <- eval(parse(text = paste0(dataName, "$", weights)))
-    pvData <- unlist(pvDataList)
-    pvWeights <- unlist(weightDataList)
-    i <- i + 1
+#' @param weights a vector of weights, the same length as `data[1]` used to
+#'     calculate the mean and SD across the PVs
+#' @return a List of transformed PVs with as many elements as PVs were listed in 'x'.
+transformPvs <- function(data, mT = 0, sdT = 1, weights = 1) {
+  # setup and checking
+  if (!(is.data.frame(data)||is.matrix(data))) stop("`data` must be matrix or data frame")
+  mPVs <- ncol(data)
+  for (i in seq(mPVs)) {
+    tmpV <- data[ , i]
+    if (!is.numeric((tmpV))) stop (paste0("Vectors in `data` must be numeric. Problem with column: ", i))
+    if (i == 1) {
+      tmpM <- tmpV
+    } else {
+      tmpM <- cbind (tmpM, tmpV)
+    }
   }
-
-  if (debug == TRUE) {
-    print(utils::str(pvDataList))
-    # tmpCheckMe<<- pvDataList
-    print("object tmpCheckMe added to global envrionemt for debugging")
+  tData <- as.matrix(tmpM)
+  if (ncol(tData) != mPVs) stop ("Something funky happened")
+  
+  # check all PVs are not missing
+  tDataL <- as.vector(tData)
+  if (any(is.na(tDataL))) stop("PVs must be complete data - missing not allowed")
+  # set any NA weights to 0
+  if(weights == 1) weights <- rep(1, length(tDataL))
+  if (!is.numeric(weights)) stop("weights must be numeric")
+  if (any(is.na(weights))) {
+    message("missing weights set to 0")
+    weights[is.na(weights)] <- 0
   }
-
+  if (length(weights) != length(tDataL)) stop ("weights must be the same length as PVs")
+  
   # calc mean and var pooled over PVs
-  pvM <- stats::weighted.mean(pvData, pvWeights)
-  pvVar <- (sum(pvWeights) / (sum(pvWeights)^2 - sum(pvWeights^2))) * sum(pvWeights * (pvData - pvM)^2)
+  pvM <- stats::weighted.mean(tDataL, weights)
+  pvVar <- (sum(weights) / (sum(weights)^2 - sum(weights^2))) * sum(weights * (tDataL - pvM)^2)
   pvSd <- sqrt(pvVar)
 
-  # use values to create tranformed PVs in results
-  # such that PV_Ti = A × PV_Ui + B, where T = transformed, U = untransofrmed,PV = verctor of all PVs combined
+  # use values to create transformed PVs in results
+  # such that PV_Ti = A × PV_Ui + B, where T = transformed, U = untransformed,PV = vector of all PVs combined
   # SD = desired SD
   # M = desired mean
   # A = SD/sd(PV), B = M - A*mean(PV_U)
+  results <- list()
   myA <- sdT/pvSd
-  myB <- mT - myA* pvM
-  i <- 1
-  for (pv in x) {
-    results[[i]] <- eval(parse(text = paste0(myA, "*", dataName, "$", pv, "+", myB)))
-    i <- i + 1
-  }
+  myB <- mT - myA * pvM
+  results <- myA * tDataL + myB
+  results <- matrix(results, ncol = mPVs)
 
   # results["pvM"] <- pvM
   # results["pvVar"] <- pvVar
